# HG changeset patch
# Node ID c2310a221695
# Parent  5cde734cf63d
diff --git a/pidgin/meson.build b/pidgin/meson.build
--- a/pidgin/meson.build
+++ b/pidgin/meson.build
@@ -23,7 +23,7 @@
 	'pidginaccountfilterconnected.c',
 	'pidginaccountfilterprotocol.c',
 	'pidginaccountmanager.c',
-	'pidginaccountrow.c',
+	'pidginaccountmanagerrow.c',
 	'pidginaccountsdisabledmenu.c',
 	'pidginaccountsenabledmenu.c',
 	'pidginactiongroup.c',
@@ -90,7 +90,7 @@
 	'pidginaccountfilterconnected.h',
 	'pidginaccountfilterprotocol.h',
 	'pidginaccountmanager.h',
-	'pidginaccountrow.h',
+	'pidginaccountmanagerrow.h',
 	'pidginaccountsdisabledmenu.h',
 	'pidginaccountsenabledmenu.h',
 	'pidginactiongroup.h',
diff --git a/pidgin/pidginaccountmanager.c b/pidgin/pidginaccountmanager.c
--- a/pidgin/pidginaccountmanager.c
+++ b/pidgin/pidginaccountmanager.c
@@ -28,7 +28,7 @@
 
 #include "pidgincore.h"
 #include "pidginaccounteditor.h"
-#include "pidginaccountrow.h"
+#include "pidginaccountmanagerrow.h"
 
 struct _PidginAccountManager {
 	GtkDialog parent;
@@ -63,7 +63,7 @@
 		return NULL;
 	}
 
-	return pidgin_account_row_new(PURPLE_ACCOUNT(item));
+	return pidgin_account_manager_row_new(PURPLE_ACCOUNT(item));
 }
 
 static void
@@ -134,8 +134,10 @@
 {
 	PurpleAccount *account = NULL;
 	PidginAccountManager *manager = data;
+	PidginAccountManagerRow *manager_row = NULL;
 
-	account = pidgin_account_row_get_account(PIDGIN_ACCOUNT_ROW(row));
+	manager_row = PIDGIN_ACCOUNT_MANAGER_ROW(row);
+	account = pidgin_account_manager_row_get_account(manager_row);
 
 	pidgin_account_manager_real_edit_account(manager, account, FALSE);
 }
diff --git a/pidgin/pidginaccountrow.c b/pidgin/pidginaccountmanagerrow.c
rename from pidgin/pidginaccountrow.c
rename to pidgin/pidginaccountmanagerrow.c
--- a/pidgin/pidginaccountrow.c
+++ b/pidgin/pidginaccountmanagerrow.c
@@ -24,9 +24,9 @@
 
 #include <adwaita.h>
 
-#include "pidgin/pidginaccountrow.h"
+#include "pidgin/pidginaccountmanagerrow.h"
 
-struct _PidginAccountRow {
+struct _PidginAccountManagerRow {
 	GtkListBoxRow parent;
 
 	PurpleAccount *account;
@@ -48,7 +48,7 @@
  * Helpers
  *****************************************************************************/
 static void
-pidgin_account_row_refresh_buddy_icon(PidginAccountRow *row) {
+pidgin_account_manager_row_refresh_buddy_icon(PidginAccountManagerRow *row) {
 	PurpleImage *image = NULL;
 
 #warning FIX call this in the right place when buddy icons are better and can autorefresh
@@ -73,7 +73,7 @@
 }
 
 static void
-pidgin_account_row_refresh_status(PidginAccountRow *row) {
+pidgin_account_manager_row_refresh_status(PidginAccountManagerRow *row) {
 	const char *status = NULL;
 	gboolean connected = FALSE;
 	gboolean error = FALSE;
@@ -126,38 +126,38 @@
  * Callbacks
  *****************************************************************************/
 static void
-pidgin_account_row_state_changed_cb(G_GNUC_UNUSED GObject *obj,
-                                    G_GNUC_UNUSED GParamSpec *pspec,
-                                    gpointer data)
+pidgin_account_manager_row_state_changed_cb(G_GNUC_UNUSED GObject *obj,
+                                            G_GNUC_UNUSED GParamSpec *pspec,
+                                            gpointer data)
 {
-	PidginAccountRow *row = data;
+	PidginAccountManagerRow *row = data;
 
-	pidgin_account_row_refresh_status(row);
+	pidgin_account_manager_row_refresh_status(row);
 }
 
 static void
-pidgin_account_row_connection_changed_cb(G_GNUC_UNUSED GObject *obj,
-                                         G_GNUC_UNUSED GParamSpec *pspec,
-                                         gpointer data)
+pidgin_account_manager_row_connection_changed_cb(G_GNUC_UNUSED GObject *obj,
+                                                 G_GNUC_UNUSED GParamSpec *pspec,
+                                                 gpointer data)
 {
-	PidginAccountRow *row = data;
+	PidginAccountManagerRow *row = data;
 	PurpleConnection *connection = NULL;
 
 	connection = purple_account_get_connection(row->account);
 	if(PURPLE_IS_CONNECTION(connection)) {
 		g_signal_connect_object(connection, "notify::state",
-		                        G_CALLBACK(pidgin_account_row_state_changed_cb),
+		                        G_CALLBACK(pidgin_account_manager_row_state_changed_cb),
 		                        row, 0);
 	}
 
-	pidgin_account_row_refresh_status(row);
+	pidgin_account_manager_row_refresh_status(row);
 }
 
 static void
-pidgin_account_row_enable_state_set_cb(G_GNUC_UNUSED GtkSwitch *sw,
-                                       gboolean state, gpointer data)
+pidgin_account_manager_row_enable_state_set_cb(G_GNUC_UNUSED GtkSwitch *sw,
+                                               gboolean state, gpointer data)
 {
-	PidginAccountRow *row = data;
+	PidginAccountManagerRow *row = data;
 	PurpleAccount *account = row->account;
 
 	if(purple_account_get_enabled(account) == state) {
@@ -174,9 +174,9 @@
 }
 
 static char *
-pidgin_account_row_buddyicon_cb(G_GNUC_UNUSED GObject *self,
-                                PurpleAccount *account,
-                                G_GNUC_UNUSED gpointer data)
+pidgin_account_manager_row_buddyicon_cb(G_GNUC_UNUSED GObject *self,
+                                        PurpleAccount *account,
+                                        G_GNUC_UNUSED gpointer data)
 {
 	const char *buddy_icon_path = NULL;
 	char *path = NULL;
@@ -194,9 +194,9 @@
 }
 
 static char *
-pidgin_account_row_protocol_name_cb(G_GNUC_UNUSED GObject *self,
-                                    PurpleAccount *account,
-                                    G_GNUC_UNUSED gpointer data)
+pidgin_account_manager_row_protocol_name_cb(G_GNUC_UNUSED GObject *self,
+                                            PurpleAccount *account,
+                                            G_GNUC_UNUSED gpointer data)
 {
 	const char *name = _("Unknown");
 
@@ -211,9 +211,9 @@
 }
 
 static char *
-pidgin_account_row_protocol_icon_cb(G_GNUC_UNUSED GObject *self,
-                                    PurpleAccount *account,
-                                    G_GNUC_UNUSED gpointer data)
+pidgin_account_manager_row_protocol_icon_cb(G_GNUC_UNUSED GObject *self,
+                                            PurpleAccount *account,
+                                            G_GNUC_UNUSED gpointer data)
 {
 	const char *icon_name = NULL;
 
@@ -248,8 +248,10 @@
 }
 
 static void
-pidgin_account_row_remove_cb(G_GNUC_UNUSED GtkButton *self, gpointer data) {
-	PidginAccountRow *row = data;
+pidgin_account_manager_row_remove_cb(G_GNUC_UNUSED GtkButton *self,
+                                     gpointer data)
+{
+	PidginAccountManagerRow *row = data;
 	GtkRoot *root = NULL;
 	AdwMessageDialog *dialog = NULL;
 	PurpleContactInfo *info = NULL;
@@ -258,8 +260,9 @@
 
 	info = PURPLE_CONTACT_INFO(row->account);
 	name = purple_contact_info_get_name_for_display(info);
-	protocol_name = pidgin_account_row_protocol_name_cb(NULL, row->account,
-	                                                    NULL);
+	protocol_name = pidgin_account_manager_row_protocol_name_cb(NULL,
+	                                                            row->account,
+	                                                            NULL);
 
 	root = gtk_widget_get_root(GTK_WIDGET(row));
 	dialog = ADW_MESSAGE_DIALOG(adw_message_dialog_new(GTK_WINDOW(root),
@@ -288,17 +291,19 @@
 /******************************************************************************
  * GObject Implementation
  *****************************************************************************/
-G_DEFINE_TYPE(PidginAccountRow, pidgin_account_row, GTK_TYPE_LIST_BOX_ROW)
+G_DEFINE_TYPE(PidginAccountManagerRow, pidgin_account_manager_row,
+              GTK_TYPE_LIST_BOX_ROW)
 
 static void
-pidgin_account_row_get_property(GObject *obj, guint param_id, GValue *value,
-                                GParamSpec *pspec)
+pidgin_account_manager_row_get_property(GObject *obj, guint param_id,
+                                        GValue *value, GParamSpec *pspec)
 {
-	PidginAccountRow *row = PIDGIN_ACCOUNT_ROW(obj);
+	PidginAccountManagerRow *row = PIDGIN_ACCOUNT_MANAGER_ROW(obj);
 
 	switch(param_id) {
 		case PROP_ACCOUNT:
-			g_value_set_object(value, pidgin_account_row_get_account(row));
+			g_value_set_object(value,
+			                   pidgin_account_manager_row_get_account(row));
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, param_id, pspec);
@@ -307,14 +312,15 @@
 }
 
 static void
-pidgin_account_row_set_property(GObject *obj, guint param_id,
+pidgin_account_manager_row_set_property(GObject *obj, guint param_id,
                                 const GValue *value, GParamSpec *pspec)
 {
-	PidginAccountRow *row = PIDGIN_ACCOUNT_ROW(obj);
+	PidginAccountManagerRow *row = PIDGIN_ACCOUNT_MANAGER_ROW(obj);
 
 	switch(param_id) {
 		case PROP_ACCOUNT:
-			pidgin_account_row_set_account(row, g_value_get_object(value));
+			pidgin_account_manager_row_set_account(row,
+			                                       g_value_get_object(value));
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, param_id, pspec);
@@ -323,35 +329,35 @@
 }
 
 static void
-pidgin_account_row_finalize(GObject *obj) {
-	PidginAccountRow *row = PIDGIN_ACCOUNT_ROW(obj);
+pidgin_account_manager_row_finalize(GObject *obj) {
+	PidginAccountManagerRow *row = PIDGIN_ACCOUNT_MANAGER_ROW(obj);
 
 	g_clear_object(&row->account);
 
-	G_OBJECT_CLASS(pidgin_account_row_parent_class)->finalize(obj);
+	G_OBJECT_CLASS(pidgin_account_manager_row_parent_class)->finalize(obj);
 }
 
 static void
-pidgin_account_row_init(PidginAccountRow *row) {
+pidgin_account_manager_row_init(PidginAccountManagerRow *row) {
 	gtk_widget_init_template(GTK_WIDGET(row));
 
-	pidgin_account_row_refresh_buddy_icon(row);
-	pidgin_account_row_refresh_status(row);
+	pidgin_account_manager_row_refresh_buddy_icon(row);
+	pidgin_account_manager_row_refresh_status(row);
 }
 
 static void
-pidgin_account_row_class_init(PidginAccountRowClass *klass) {
+pidgin_account_manager_row_class_init(PidginAccountManagerRowClass *klass) {
 	GObjectClass *obj_class = G_OBJECT_CLASS(klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
 
-	obj_class->finalize = pidgin_account_row_finalize;
-	obj_class->get_property = pidgin_account_row_get_property;
-	obj_class->set_property = pidgin_account_row_set_property;
+	obj_class->finalize = pidgin_account_manager_row_finalize;
+	obj_class->get_property = pidgin_account_manager_row_get_property;
+	obj_class->set_property = pidgin_account_manager_row_set_property;
 
 	/* properties */
 
 	/**
-	 * PidginAccountRow:account:
+	 * PidginAccountManagerRow:account:
 	 *
 	 * The account that this row will be representing.
 	 *
@@ -367,50 +373,53 @@
 
 	gtk_widget_class_set_template_from_resource(
 	    widget_class,
-	    "/im/pidgin/Pidgin3/Accounts/account-row.ui"
+	    "/im/pidgin/Pidgin3/Accounts/manager-row.ui"
 	);
 
-	gtk_widget_class_bind_template_child(widget_class, PidginAccountRow,
+	gtk_widget_class_bind_template_child(widget_class, PidginAccountManagerRow,
 	                                     enabled);
-	gtk_widget_class_bind_template_child(widget_class, PidginAccountRow,
+	gtk_widget_class_bind_template_child(widget_class, PidginAccountManagerRow,
 	                                     avatar);
-	gtk_widget_class_bind_template_child(widget_class, PidginAccountRow,
+	gtk_widget_class_bind_template_child(widget_class, PidginAccountManagerRow,
 	                                     name);
-	gtk_widget_class_bind_template_child(widget_class, PidginAccountRow,
+	gtk_widget_class_bind_template_child(widget_class, PidginAccountManagerRow,
 	                                     status);
 
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_account_row_enable_state_set_cb);
+	                                        pidgin_account_manager_row_enable_state_set_cb);
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_account_row_buddyicon_cb);
+	                                        pidgin_account_manager_row_buddyicon_cb);
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_account_row_protocol_name_cb);
+	                                        pidgin_account_manager_row_protocol_name_cb);
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_account_row_protocol_icon_cb);
+	                                        pidgin_account_manager_row_protocol_icon_cb);
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_account_row_remove_cb);
+	                                        pidgin_account_manager_row_remove_cb);
 }
 
 /******************************************************************************
  * Public API
  *****************************************************************************/
 GtkWidget *
-pidgin_account_row_new(PurpleAccount *account) {
-	return g_object_new(PIDGIN_TYPE_ACCOUNT_ROW, "account", account, NULL);
+pidgin_account_manager_row_new(PurpleAccount *account) {
+	return g_object_new(PIDGIN_TYPE_ACCOUNT_MANAGER_ROW, "account", account,
+	                    NULL);
 }
 
 PurpleAccount *
-pidgin_account_row_get_account(PidginAccountRow *row) {
-	g_return_val_if_fail(PIDGIN_IS_ACCOUNT_ROW(row), NULL);
+pidgin_account_manager_row_get_account(PidginAccountManagerRow *row) {
+	g_return_val_if_fail(PIDGIN_IS_ACCOUNT_MANAGER_ROW(row), NULL);
 
 	return row->account;
 }
 
 void
-pidgin_account_row_set_account(PidginAccountRow *row, PurpleAccount *account) {
+pidgin_account_manager_row_set_account(PidginAccountManagerRow *row,
+                                       PurpleAccount *account)
+{
 	PurpleAccount *old = NULL;
 
-	g_return_if_fail(PIDGIN_IS_ACCOUNT_ROW(row));
+	g_return_if_fail(PIDGIN_IS_ACCOUNT_MANAGER_ROW(row));
 
 	old = (row->account != NULL) ? g_object_ref(row->account) : NULL;
 
@@ -420,24 +429,24 @@
 
 			if(PURPLE_IS_CONNECTION(connection)) {
 				g_signal_handlers_disconnect_by_func(connection,
-				                                     pidgin_account_row_state_changed_cb,
+				                                     pidgin_account_manager_row_state_changed_cb,
 				                                     row);
 			}
 
 			g_signal_handlers_disconnect_by_func(old,
-			                                     pidgin_account_row_connection_changed_cb,
+			                                     pidgin_account_manager_row_connection_changed_cb,
 			                                     row);
 		}
 
 		if(PURPLE_IS_ACCOUNT(account)) {
 			g_signal_connect_object(account, "notify::connection",
-			                        G_CALLBACK(pidgin_account_row_connection_changed_cb),
+			                        G_CALLBACK(pidgin_account_manager_row_connection_changed_cb),
 			                        row, 0);
 			g_signal_connect_object(account, "notify::error",
-			                        G_CALLBACK(pidgin_account_row_state_changed_cb),
+			                        G_CALLBACK(pidgin_account_manager_row_state_changed_cb),
 			                        row, 0);
-			pidgin_account_row_refresh_buddy_icon(row);
-			pidgin_account_row_refresh_status(row);
+			pidgin_account_manager_row_refresh_buddy_icon(row);
+			pidgin_account_manager_row_refresh_status(row);
 		}
 
 		g_object_notify_by_pspec(G_OBJECT(row), properties[PROP_ACCOUNT]);
diff --git a/pidgin/resources/Accounts/account-row.ui b/pidgin/resources/Accounts/manager-row.ui
rename from pidgin/resources/Accounts/account-row.ui
rename to pidgin/resources/Accounts/manager-row.ui
--- a/pidgin/resources/Accounts/account-row.ui
+++ b/pidgin/resources/Accounts/manager-row.ui
@@ -22,7 +22,7 @@
   <!-- interface-name Pidgin -->
   <!-- interface-description Internet Messenger -->
   <!-- interface-copyright Pidgin Developers <devel@pidgin.im> -->
-  <template class="PidginAccountRow" parent="GtkListBoxRow">
+  <template class="PidginAccountManagerRow" parent="GtkListBoxRow">
     <property name="selectable">0</property>
     <property name="child">
       <object class="GtkBox">
@@ -32,11 +32,11 @@
           <object class="GtkSwitch" id="enabled">
             <binding name="active">
               <lookup name="enabled" type="PurpleAccount">
-                <lookup name="account">PidginAccountRow</lookup>
+                <lookup name="account">PidginAccountManagerRow</lookup>
               </lookup>
             </binding>
             <property name="valign">center</property>
-            <signal name="state-set" handler="pidgin_account_row_enable_state_set_cb" swapped="no"/>
+            <signal name="state-set" handler="pidgin_account_manager_row_enable_state_set_cb" swapped="no"/>
           </object>
         </child>
         <child>
@@ -44,7 +44,7 @@
             <property name="size">48</property>
             <binding name="text">
               <lookup name="name-for-display" type="PurpleContactInfo">
-                <lookup name="account">PidginAccountRow</lookup>
+                <lookup name="account">PidginAccountManagerRow</lookup>
               </lookup>
             </binding>
           </object>
@@ -59,7 +59,7 @@
                 <property name="xalign">0</property>
                 <binding name="label">
                   <lookup name="name-for-display" type="PurpleContactInfo">
-                    <lookup name="account">PidginAccountRow</lookup>
+                    <lookup name="account">PidginAccountManagerRow</lookup>
                   </lookup>
                 </binding>
               </object>
@@ -80,8 +80,8 @@
             <child>
               <object class="GtkImage">
                 <binding name="icon-name">
-                  <closure type="gchararray" function="pidgin_account_row_protocol_icon_cb">
-                    <lookup name="account">PidginAccountRow</lookup>
+                  <closure type="gchararray" function="pidgin_account_manager_row_protocol_icon_cb">
+                    <lookup name="account">PidginAccountManagerRow</lookup>
                   </closure>
                 </binding>
               </object>
@@ -89,8 +89,8 @@
             <child>
               <object class="GtkLabel">
                 <binding name="label">
-                  <closure type="gchararray" function="pidgin_account_row_protocol_name_cb">
-                    <lookup name="account">PidginAccountRow</lookup>
+                  <closure type="gchararray" function="pidgin_account_manager_row_protocol_name_cb">
+                    <lookup name="account">PidginAccountManagerRow</lookup>
                   </closure>
                 </binding>
                 <property name="css-classes">dim-label</property>
@@ -105,7 +105,7 @@
 error</property>
             <property name="icon-name">list-remove-symbolic</property>
             <property name="valign">center</property>
-            <signal name="clicked" handler="pidgin_account_row_remove_cb" swapped="no"/>
+            <signal name="clicked" handler="pidgin_account_manager_row_remove_cb" swapped="no"/>
           </object>
         </child>
         <child>
diff --git a/pidgin/resources/pidgin.gresource.xml b/pidgin/resources/pidgin.gresource.xml
--- a/pidgin/resources/pidgin.gresource.xml
+++ b/pidgin/resources/pidgin.gresource.xml
@@ -4,11 +4,11 @@
     <file compressed="true" preprocess="xml-stripblanks">About/about.ui</file>
     <file compressed="true">About/about.md</file>
     <file compressed="true" preprocess="json-stripblanks">About/credits.json</file>
-    <file compressed="true" preprocess="xml-stripblanks">Accounts/account-row.ui</file>
     <file compressed="true" preprocess="xml-stripblanks">Accounts/chooser.ui</file>
     <file compressed="true" preprocess="xml-stripblanks">Accounts/display.ui</file>
     <file compressed="true" preprocess="xml-stripblanks">Accounts/editor.ui</file>
     <file compressed="true" preprocess="xml-stripblanks">Accounts/manager.ui</file>
+    <file compressed="true" preprocess="xml-stripblanks">Accounts/manager-row.ui</file>
     <file compressed="true" preprocess="xml-stripblanks">avatar.ui</file>
     <file compressed="true" preprocess="xml-stripblanks">BuddyList/window.ui</file>
     <file compressed="true" preprocess="xml-stripblanks">Conversations/conversation.ui</file>
diff --git a/po/POTFILES.in b/po/POTFILES.in
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -252,7 +252,7 @@
 pidgin/pidginaccountfilterconnected.c
 pidgin/pidginaccountfilterprotocol.c
 pidgin/pidginaccountmanager.c
-pidgin/pidginaccountrow.c
+pidgin/pidginaccountmanagerrow.c
 pidgin/pidginaccountsdisabledmenu.c
 pidgin/pidginaccountsenabledmenu.c
 pidgin/pidginactiongroup.c
@@ -300,10 +300,10 @@
 pidgin/prefs/pidginproxyprefs.c
 pidgin/prefs/pidginvvprefs.c
 pidgin/resources/About/about.ui
-pidgin/resources/Accounts/account-row.ui
 pidgin/resources/Accounts/chooser.ui
 pidgin/resources/Accounts/editor.ui
 pidgin/resources/Accounts/manager.ui
+pidgin/resources/Accounts/manager-row.ui
 pidgin/resources/avatar.ui
 pidgin/resources/BuddyList/window.ui
 pidgin/resources/Conversations/infopane.ui

diff --git a/pidgin/pidginaccountrow.h b/pidgin/pidginaccountmanagerrow.h
rename from pidgin/pidginaccountrow.h
rename to pidgin/pidginaccountmanagerrow.h
--- a/pidgin/pidginaccountrow.h
+++ b/pidgin/pidginaccountmanagerrow.h
@@ -24,41 +24,41 @@
 # error "only <pidgin.h> may be included directly"
 #endif
 
-#ifndef PIDGIN_ACCOUNT_ROW_H
-#define PIDGIN_ACCOUNT_ROW_H
+#ifndef PIDGIN_ACCOUNT_MANAGER_ROW_H
+#define PIDGIN_ACCOUNT_MANAGER_ROW_H
 
 #include <gtk/gtk.h>
 
 #include <purple.h>
 
 /**
- * PidginAccountRow:
+ * PidginAccountManagerRow:
  *
  * A [class@Gtk.ListBoxRow] subclass to display a [class@Purple.Account].
  *
  * Since: 3.0.0
  */
 
-#define PIDGIN_TYPE_ACCOUNT_ROW (pidgin_account_row_get_type())
-G_DECLARE_FINAL_TYPE(PidginAccountRow, pidgin_account_row, PIDGIN, ACCOUNT_ROW,
-                     GtkListBoxRow)
+#define PIDGIN_TYPE_ACCOUNT_MANAGER_ROW (pidgin_account_manager_row_get_type())
+G_DECLARE_FINAL_TYPE(PidginAccountManagerRow, pidgin_account_manager_row,
+                     PIDGIN, ACCOUNT_MANAGER_ROW, GtkListBoxRow)
 
 G_BEGIN_DECLS
 
 /**
- * pidgin_account_row_new:
+ * pidgin_account_manager_row_new:
  * @account: (nullable): The account to represent.
  *
  * Creates a new #PidginAccountRow to display a [class@Purple.Account].
  *
  * Returns: (transfer full): The new account row.
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_account_row_new(PurpleAccount *account);
+GtkWidget *pidgin_account_manager_row_new(PurpleAccount *account);
 
 /**
- * pidgin_account_row_get_account:
+ * pidgin_account_manager_row_get_account:
  * @row: The instance.
  *
  * Gets the [class@Purple.Account] that @row is displaying.
@@ -67,10 +67,10 @@
  *
  * Since: 3.0.0
  */
-PurpleAccount *pidgin_account_row_get_account(PidginAccountRow *row);
+PurpleAccount *pidgin_account_manager_row_get_account(PidginAccountManagerRow *row);
 
 /**
- * pidgin_account_row_set_account:
+ * pidgin_account_manager_row_set_account:
  * @row: The instance.
  * @account: (nullable): The new account to set, or %NULL to unset.
  *
@@ -78,8 +78,8 @@
  *
  * Since: 3.0.0
  */
-void pidgin_account_row_set_account(PidginAccountRow *row, PurpleAccount *account);
+void pidgin_account_manager_row_set_account(PidginAccountManagerRow *row, PurpleAccount *account);
 
 G_END_DECLS
 
-#endif /* PIDGIN_ACCOUNT_ROW_H */
+#endif /* PIDGIN_ACCOUNT_MANAGER_ROW_H */
@@ -24,41 +24,41 @@
  * @account: (nullable): The account to represent.
  *
- * Creates a new #PidginAccountRow to display a [class@Purple.Account].
+ * Creates a new #PidginAccountManagerRow to display a [class@Purple.Account].
  *
  * Returns: (transfer full): The new account row.